@@ -116,10 +116,6 @@ module Data.PQueue.Prio.Max (
   )
   where
 
-import Control.Applicative (Applicative, (<$>))
-import Data.Monoid (Monoid(mempty, mappend, mconcat))
-import Data.Traversable (Traversable(traverse))
-import Data.Foldable (Foldable, foldr, foldl)
 import Data.Maybe (fromMaybe)
 import Data.PQueue.Prio.Max.Internals
 
@@ -127,7 +123,7 @@ import Data.PQueue.Prio.Max.Internals
 import Data.Semigroup (Semigroup((<>)))
 #endif
 
-import Prelude hiding (map, filter, break, span, takeWhile, dropWhile, splitAt, take, drop, (!!), null, foldr, foldl)
+import Prelude hiding (map, filter, break, span, takeWhile, dropWhile, splitAt, take, drop, (!!), null)
 
 import qualified Data.PQueue.Prio.Min as Q
 
